==> byexample-8.0.1.tar.gz: byexample-8.0.1/byexample/byexample.py <==
from __future__ import unicode_literals
from .cache import RegexCache
from .jobs import Jobs, Status, allow_sigint
import os, sys

def execute_examples(filename, sigint_handler):
    global cache, harvester, executor, options, human_args, dry
    from .common import human_exceptions

    with human_exceptions("File '%s':" % filename, *human_args) as exc, \
            cache.synced(label=filename), \
            allow_sigint(sigint_handler):
        examples = harvester.get_examples_from_file(filename)
        if dry:
            return executor.dry_execute(examples, filename)
        else:
            return executor.execute(examples, filename)

    user_aborted = isinstance(exc.get('exc'), KeyboardInterrupt)
    error = not user_aborted
    return True, True, user_aborted, error

def main(args=None):
    global cache, harvester, executor, options, human_args, dry

    cache_disabled = os.getenv('BYEXAMPLE_CACHE_DISABLED', "1") != "0"
    cache_verbose  = os.getenv('BYEXAMPLE_CACHE_VERBOSE', "0") != "0"
    cache = RegexCache('0', cache_disabled, cache_verbose)

    with cache.activated(auto_sync=True, label="0"):
        from .cmdline import parse_args
        from .common import human_exceptions
        from .init import init

        args = parse_args(args)

        dry = args.dry
        human_args = [args.verbosity, args.quiet]
        with human_exceptions('During the initialization phase:', *human_args) as exc:
            testfiles, harvester, executor, options = init(args)

        if exc:
            sys.exit(Status.error)

        jobs = Jobs(args.jobs, args.verbosity)
        return jobs.run(execute_examples, testfiles, options['fail_fast'])

==> byexample-9.2.0.tar.gz: byexample-9.2.0/byexample/byexample.py <==
from __future__ import unicode_literals
import os, sys

if sys.version_info < (3, 0):
    print(
        "Are you using Python 2.x? Byexample no longer runs in that version. Please upgrade your Python environment."
    )
    sys.exit(1)

from .cache import RegexCache
from .jobs import Jobs, Status, allow_sigint
from .log import init_log_system


def execute_examples(filename, sigint_handler):
    global cache, harvester, executor, options, dry
    from .common import human_exceptions

    with human_exceptions("processing the file '%s'" % filename) as exc, \
            cache.synced(label=filename), \
            allow_sigint(sigint_handler):
        examples = harvester.get_examples_from_file(filename)
        if dry:
            return executor.dry_execute(examples, filename)
        else:
            return executor.execute(examples, filename)

    user_aborted = isinstance(exc.get('exc'), KeyboardInterrupt)
    error = not user_aborted
    return True, True, user_aborted, error


def main(args=None):
    global cache, harvester, executor, options, dry

    init_log_system()

    cache_disabled = os.getenv('BYEXAMPLE_CACHE_DISABLED', "1") != "0"
    cache_verbose = os.getenv('BYEXAMPLE_CACHE_VERBOSE', "0") != "0"
    if sys.version_info > (3, 7):
        # The feature is not supported for Python 3.8
        cache_disabled = True
    cache = RegexCache('0', cache_disabled, cache_verbose)

    with cache.activated(auto_sync=True, label="0"):
        from .cmdline import parse_args
        from .common import human_exceptions
        from .init import init

        args = parse_args(args)

        dry = args.dry
        with human_exceptions('initializing byexample') as exc:
            testfiles, harvester, executor, options = init(args)

        if exc:
            sys.exit(Status.error)

        jobs = Jobs(args.jobs)
        return jobs.run(execute_examples, testfiles, options['fail_fast'])
